/*******************************************************************************
* File Name: ADC_DelSig_ISR_intc.c  
* Version GetMajorVersion().GetMinorVersion()
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright (2008), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is 
* protected by and subject to worldwide patent protection (United States and 
* foreign), United States copyright laws and international treaty provisions. 
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable 
* license to copy, use, modify, create derivative works of, and compile the 
* Cypress Source Code and derivative works for the sole purpose of creating 
* custom software in support of licensee product to be used only in conjunction 
* with a Cypress integrated circuit as specified in the applicable agreement. 
* Any reproduction, modification, translation, compilation, or representation of 
* this software except as specified above is prohibited without the express 
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. Use may be 
* limited by and subject to the applicable Cypress software license agreement. 
*******************************************************************************/


#include <CYDEVICE.H>
#include <ADC_DelSig_ISR.H>




/* Address of the INTC.VECT[x] register that contains the Address of the ADC_DelSig_ISR ISR. */
#define ADC_DelSig_ISR_INTC_VECTOR              ((reg16 *) ADC_DelSig_ISR__INTC_VECT)

/* Address of the ADC_DelSig_ISR ISR priority. */
#define ADC_DelSig_ISR_INTC_PRIOR             ((reg8 *) ADC_DelSig_ISR__INTC_PRIOR_REG)

/* Priority of the ADC_DelSig_ISR interrupt. */
#define ADC_DelSig_ISR_INTC_PRIOR_NUMBER      ADC_DelSig_ISR__INTC_PRIOR_NUM

/* Address of the INTC.SET_EN[x] byte to bit enable ADC_DelSig_ISR interrupt. */
#define ADC_DelSig_ISR_INTC_SET_EN            ((reg8 *) ADC_DelSig_ISR__INTC_SET_EN_REG)

/* Address of the INTC.CLR_EN[x] register to bit clear the ADC_DelSig_ISR interrupt. */
#define ADC_DelSig_ISR_INTC_CLR_EN            ((reg8 *) ADC_DelSig_ISR__INTC_CLR_EN_REG)

/* Address of the INTC.SET_PD[x] register to set the ADC_DelSig_ISR interrupt state to pending. */
#define ADC_DelSig_ISR_INTC_SET_PD            ((reg8 *) ADC_DelSig_ISR__INTC_SET_PD_REG)

/* Address of the INTC.CLR_PD[x] register to clear the ADC_DelSig_ISR interrupt. */
#define ADC_DelSig_ISR_INTC_CLR_PD            ((reg8 *) ADC_DelSig_ISR__INTC_CLR_PD_REG)


/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START ADC_DelSig_ISR_intc` */
#include "SPIS.h"
/* `#END` */


/*******************************************************************************
* Function Name: ADC_DelSig_ISR_Start
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   void.
*
*
* Return:
*   void.
*
*******************************************************************************/
void ADC_DelSig_ISR_Start(void)
{
    /* For all we know the interrupt is active. */
    ADC_DelSig_ISR_Disable();

    /* Set the ISR to point to the ADC_DelSig_ISR Interrupt. */
    ADC_DelSig_ISR_SetVector(ADC_DelSig_ISR_Interrupt);

    /* Set the priority. */
    ADC_DelSig_ISR_SetPriority(ADC_DelSig_ISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    ADC_DelSig_ISR_Enable();
}

/*******************************************************************************
* Function Name: ADC_DelSig_ISR_Stop
********************************************************************************
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
void ADC_DelSig_ISR_Stop(void)
{
    /* Disable this interrupt. */
    ADC_DelSig_ISR_Disable();

    /* Set the ISR to point to the passive one. */
//    ADC_DelSig_ISR_SetVector(CyDefaultInterrupt);
}

/*******************************************************************************
* Function Name: ADC_DelSig_ISR_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for ADC_DelSig_ISR.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
*
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
CY_ISR(ADC_DelSig_ISR_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START ADC_DelSig_ISR_Interrupt` */
	uint16 ADC_DelSig_data;
	
	// Read the ADC_DelSig register value
	//ADC_DelSig_data = ADC_DelSig_GetResult8();
	ADC_DelSig_data = 0xAA;
	
	// Write the ADC_DelSig value to the SPI Tx register and keep it ready for transfer
	SPIS_WriteByte(ADC_DelSig_data);
	
    /* `#END` */
}


/*******************************************************************************
* Function Name: ADC_DelSig_ISR_SetVector
********************************************************************************
* Summary:
*   Change the ISR vector for the Interrupt.
*
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ADC_DelSig_ISR_SetVector(cyisraddress address)
{
    CY_SET_REG16(ADC_DelSig_ISR_INTC_VECTOR, (uint16) address);
}

/*******************************************************************************
* Function Name: ADC_DelSig_ISR_GetVector
********************************************************************************
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*
*******************************************************************************/
cyisraddress ADC_DelSig_ISR_GetVector(void)
{
    return (cyisraddress) CY_GET_REG16(ADC_DelSig_ISR_INTC_VECTOR);
}

/*******************************************************************************
* Function Name: ADC_DelSig_ISR_SetPriority
********************************************************************************
* Summary:
*   Sets the Priority of the Interrupt.
*
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ADC_DelSig_ISR_SetPriority(uint8 priority)
{
    *ADC_DelSig_ISR_INTC_PRIOR = priority << 5;
}

/*******************************************************************************
* Function Name: ADC_DelSig_ISR_GetPriority
********************************************************************************
* Summary:
*   Gets the Priority of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
*******************************************************************************/
uint8 ADC_DelSig_ISR_GetPriority(void)
{
    uint8 priority;


    priority = *ADC_DelSig_ISR_INTC_PRIOR >> 5;

    return priority;
}

/*******************************************************************************
* Function Name: ADC_DelSig_ISR_Enable
********************************************************************************
* Summary:
*   Enables the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ADC_DelSig_ISR_Enable(void)
{
    /* Enable the general interrupt. */
    *ADC_DelSig_ISR_INTC_SET_EN = ADC_DelSig_ISR__INTC_MASK;
}

/*******************************************************************************
* Function Name: ADC_DelSig_ISR_GetState
********************************************************************************
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   1 if enabled, 0 if disabled.
*
*
*******************************************************************************/
uint8 ADC_DelSig_ISR_GetState(void)
{
    /* Get the state of the general interrupt. */
    return (*ADC_DelSig_ISR_INTC_SET_EN & ADC_DelSig_ISR__INTC_MASK) ? 1:0;
}

/*******************************************************************************
* Function Name: ADC_DelSig_ISR_Disable
********************************************************************************
* Summary:
*   Disables the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ADC_DelSig_ISR_Disable(void)
{
    /* Disable the general interrupt. */
    *ADC_DelSig_ISR_INTC_CLR_EN = ADC_DelSig_ISR__INTC_MASK;
}

/*******************************************************************************
* Function Name: ADC_DelSig_ISR_SetPending
********************************************************************************
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ADC_DelSig_ISR_SetPending(void)
{
    *ADC_DelSig_ISR_INTC_SET_PD = ADC_DelSig_ISR__INTC_MASK;
}

/*******************************************************************************
* Function Name: ADC_DelSig_ISR_ClearPending
********************************************************************************
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ADC_DelSig_ISR_ClearPending(void)
{
    *ADC_DelSig_ISR_INTC_CLR_PD = ADC_DelSig_ISR__INTC_MASK;
}


















































