/*******************************************************************************
* File Name: SPIS_InternalInterrupt_intc.c  
* Version 1.0
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright (2008), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is 
* protected by and subject to worldwide patent protection (United States and 
* foreign), United States copyright laws and international treaty provisions. 
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable 
* license to copy, use, modify, create derivative works of, and compile the 
* Cypress Source Code and derivative works for the sole purpose of creating 
* custom software in support of licensee product to be used only in conjunction 
* with a Cypress integrated circuit as specified in the applicable agreement. 
* Any reproduction, modification, translation, compilation, or representation of 
* this software except as specified above is prohibited without the express 
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. Use may be 
* limited by and subject to the applicable Cypress software license agreement. 
*******************************************************************************/


#include <CYDEVICE.H>
#include <SPIS_InternalInterrupt.H>




/* Address of the INTC.VECT[x] register that contains the Address of the SPIS_InternalInterrupt ISR. */
#define SPIS_InternalInterrupt_INTC_VECTOR              ((reg16 *) SPIS_InternalInterrupt__INTC_VECT)

/* Address of the SPIS_InternalInterrupt ISR priority. */
#define SPIS_InternalInterrupt_INTC_PRIOR             ((reg8 *) SPIS_InternalInterrupt__INTC_PRIOR_REG)

/* Priority of the SPIS_InternalInterrupt interrupt. */
#define SPIS_InternalInterrupt_INTC_PRIOR_NUMBER      SPIS_InternalInterrupt__INTC_PRIOR_NUM

/* Address of the INTC.SET_EN[x] byte to bit enable SPIS_InternalInterrupt interrupt. */
#define SPIS_InternalInterrupt_INTC_SET_EN            ((reg8 *) SPIS_InternalInterrupt__INTC_SET_EN_REG)

/* Address of the INTC.CLR_EN[x] register to bit clear the SPIS_InternalInterrupt interrupt. */
#define SPIS_InternalInterrupt_INTC_CLR_EN            ((reg8 *) SPIS_InternalInterrupt__INTC_CLR_EN_REG)

/* Address of the INTC.SET_PD[x] register to set the SPIS_InternalInterrupt interrupt state to pending. */
#define SPIS_InternalInterrupt_INTC_SET_PD            ((reg8 *) SPIS_InternalInterrupt__INTC_SET_PD_REG)

/* Address of the INTC.CLR_PD[x] register to clear the SPIS_InternalInterrupt interrupt. */
#define SPIS_InternalInterrupt_INTC_CLR_PD            ((reg8 *) SPIS_InternalInterrupt__INTC_CLR_PD_REG)


/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START SPIS_InternalInterrupt_intc` */

/* `#END` */


/*******************************************************************************
* Function Name: SPIS_InternalInterrupt_Start
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   void.
*
*
* Return:
*   void.
*
*******************************************************************************/
void SPIS_InternalInterrupt_Start(void)
{
    /* For all we know the interrupt is active. */
    SPIS_InternalInterrupt_Disable();

    /* Set the ISR to point to the SPIS_InternalInterrupt Interrupt. */
    SPIS_InternalInterrupt_SetVector(SPIS_InternalInterrupt_Interrupt);

    /* Set the priority. */
    SPIS_InternalInterrupt_SetPriority(SPIS_InternalInterrupt_INTC_PRIOR_NUMBER);

    /* Enable it. */
    SPIS_InternalInterrupt_Enable();
}

/*******************************************************************************
* Function Name: SPIS_InternalInterrupt_Stop
********************************************************************************
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
void SPIS_InternalInterrupt_Stop(void)
{
    /* Disable this interrupt. */
    SPIS_InternalInterrupt_Disable();

    /* Set the ISR to point to the passive one. */
//    SPIS_InternalInterrupt_SetVector(CyDefaultInterrupt);
}

/*******************************************************************************
* Function Name: SPIS_InternalInterrupt_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for SPIS_InternalInterrupt.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
*
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
CY_ISR(SPIS_InternalInterrupt_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START SPIS_InternalInterrupt_Interrupt` */

    /* `#END` */
}


/*******************************************************************************
* Function Name: SPIS_InternalInterrupt_SetVector
********************************************************************************
* Summary:
*   Change the ISR vector for the Interrupt.
*
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void SPIS_InternalInterrupt_SetVector(cyisraddress address)
{
    CY_SET_REG16(SPIS_InternalInterrupt_INTC_VECTOR, (uint16) address);
}

/*******************************************************************************
* Function Name: SPIS_InternalInterrupt_GetVector
********************************************************************************
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*
*******************************************************************************/
cyisraddress SPIS_InternalInterrupt_GetVector(void)
{
    return (cyisraddress) CY_GET_REG16(SPIS_InternalInterrupt_INTC_VECTOR);
}

/*******************************************************************************
* Function Name: SPIS_InternalInterrupt_SetPriority
********************************************************************************
* Summary:
*   Sets the Priority of the Interrupt.
*
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void SPIS_InternalInterrupt_SetPriority(uint8 priority)
{
    *SPIS_InternalInterrupt_INTC_PRIOR = priority << 5;
}

/*******************************************************************************
* Function Name: SPIS_InternalInterrupt_GetPriority
********************************************************************************
* Summary:
*   Gets the Priority of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
*******************************************************************************/
uint8 SPIS_InternalInterrupt_GetPriority(void)
{
    uint8 priority;


    priority = *SPIS_InternalInterrupt_INTC_PRIOR >> 5;

    return priority;
}

/*******************************************************************************
* Function Name: SPIS_InternalInterrupt_Enable
********************************************************************************
* Summary:
*   Enables the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void SPIS_InternalInterrupt_Enable(void)
{
    /* Enable the general interrupt. */
    *SPIS_InternalInterrupt_INTC_SET_EN = SPIS_InternalInterrupt__INTC_MASK;
}

/*******************************************************************************
* Function Name: SPIS_InternalInterrupt_GetState
********************************************************************************
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   1 if enabled, 0 if disabled.
*
*
*******************************************************************************/
uint8 SPIS_InternalInterrupt_GetState(void)
{
    /* Get the state of the general interrupt. */
    return (*SPIS_InternalInterrupt_INTC_SET_EN & SPIS_InternalInterrupt__INTC_MASK) ? 1:0;
}

/*******************************************************************************
* Function Name: SPIS_InternalInterrupt_Disable
********************************************************************************
* Summary:
*   Disables the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void SPIS_InternalInterrupt_Disable(void)
{
    /* Disable the general interrupt. */
    *SPIS_InternalInterrupt_INTC_CLR_EN = SPIS_InternalInterrupt__INTC_MASK;
}

/*******************************************************************************
* Function Name: SPIS_InternalInterrupt_SetPending
********************************************************************************
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void SPIS_InternalInterrupt_SetPending(void)
{
    *SPIS_InternalInterrupt_INTC_SET_PD = SPIS_InternalInterrupt__INTC_MASK;
}

/*******************************************************************************
* Function Name: SPIS_InternalInterrupt_ClearPending
********************************************************************************
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void SPIS_InternalInterrupt_ClearPending(void)
{
    *SPIS_InternalInterrupt_INTC_CLR_PD = SPIS_InternalInterrupt__INTC_MASK;
}


















































