/*******************************************************************************
* File Name: Port_LED.c  
* Version 1.50
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "Port_LED.h"


/*******************************************************************************
* Function Name: Port_LED_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void Port_LED_Write(uint8 value) 
{
    uint8 staticBits = Port_LED_DR & ~Port_LED_MASK;
    Port_LED_DR = staticBits | ((value << Port_LED_SHIFT) & Port_LED_MASK);
}


/*******************************************************************************
* Function Name: Port_LED_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void Port_LED_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Port_LED_0, mode);
	CyPins_SetPinDriveMode(Port_LED_1, mode);
	CyPins_SetPinDriveMode(Port_LED_2, mode);
	CyPins_SetPinDriveMode(Port_LED_3, mode);
}


/*******************************************************************************
* Function Name: Port_LED_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Port_LED_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Port_LED_Read(void) 
{
    return (Port_LED_PS & Port_LED_MASK) >> Port_LED_SHIFT;
}


/*******************************************************************************
* Function Name: Port_LED_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Port_LED_ReadDataReg(void) 
{
    return (Port_LED_DR & Port_LED_MASK) >> Port_LED_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Port_LED_INTSTAT) 

    /*******************************************************************************
    * Function Name: Port_LED_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Port_LED_ClearInterrupt(void) 
    {
        return (Port_LED_INTSTAT & Port_LED_MASK) >> Port_LED_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
